@@ -1,5 +1,6 @@
 from typing import Optional
 from ._connection import DatabaseConnection, set_gcloud_key_path
+from ._visualize import *
 
 db_connection: DatabaseConnection = None
 
@@ -79,3 +80,13 @@ def summary(**kwargs):
     return df
 
 
+def visualize(name):
+    df = summary(print=False)
+    if name.lower() == 'datasets':
+        ds = df.where(df['num_rows'] > 0).groupby('dataset').sum().dropna()
+        visualize_all_datasets(ds)
+        return
+    tables = df.where(df['dataset'] == name.upper()).dropna()
+    if len(tables) <= 0:
+        return
+    visualize_dataset(tables)
